@@ -11,7 +11,7 @@ use Exporter ();
 
 use vars qw ($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION     = '0.01' ;
+$VERSION     = 0.01;
 @EXPORT_OK   = qw (GetConfigDelta GetConfigHierarchicalDelta DumpConfigHierarchicalDelta Get_NoIdentical_Filter);
 %EXPORT_TAGS = ();
 }
@@ -292,7 +292,20 @@ sub Get_NoIdentical_Filter
 
 =head2 Get_NoIdentical_Filter
 
-Dumping a config delta with:
+	print  DumpConfigHierarchicalDelta($config_2, $config_0, Get_NoIdentical_Filter()) ;
+
+Gives:
+
+	my $expected_dump = <<EOD ;
+	Delta between 'config 2' and 'config 0'':
+	|- different 
+	|  `- CC1 
+	|     |- config 0 = 1 
+	|     `- config 2 = A 
+	`- in 'config 2' only 
+	   |- CC3 = 3 
+	   `- XYZ = xyz 
+	EOD
 
 	print  DumpConfigHierarchicalDelta($config_2, $config_0) ;	
 
@@ -311,23 +324,6 @@ Gives:
 	   `- XYZ = xyz 
   
 
-if you do not want to display the configuration variables that are identical, use:
-
-	print  DumpConfigHierarchicalDelta($config_2, $config_0, Get_NoIdentical_Filter()) ;
-
-which gives:
-
-	my $expected_dump = <<EOD ;
-	Delta between 'config 2' and 'config 0'':
-	|- different 
-	|  `- CC1 
-	|     |- config 0 = 1 
-	|     `- config 2 = A 
-	`- in 'config 2' only 
-	   |- CC3 = 3 
-	   `- XYZ = xyz 
-	EOD
-
 Returns a L<Data::TreeDumper> filter you can use to remove the 'identical' element from the delta hash.
 
 =cut
