@@ -1,6 +1,8 @@
 
 package Config::Hierarchical::Tie::ReadOnly ;
 
+#~ use base Exporter ;
+
 use strict;
 use warnings ;
 
@@ -10,7 +12,7 @@ BEGIN
 
 use vars qw ($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION     = '0.01' ;
+$VERSION     = 0.01;
 @EXPORT_OK   = qw ();
 %EXPORT_TAGS = ();
 }
@@ -41,11 +43,11 @@ Config::Hierarchical::Tie::ReadOnly - Access Hierarchical configuration containe
 				
 				INITIAL_VALUES  =>
 					[
-					{CATEGORY => 'A', NAME => 'CC1', VALUE => '1'},
-					{CATEGORY => 'B', NAME => 'CC2', VALUE => '2'},
-					{CATEGORY => 'A', NAME => 'CC3', VALUE => '3'},
-					{CATEGORY => 'B', NAME => 'CC4', VALUE => '4'},
-					{CATEGORY => 'A', NAME => 'CC5', VALUE => '5'},
+					[CATEGORY => 'A', NAME => 'CC1', VALUE => '1'],
+					[CATEGORY => 'B', NAME => 'CC2', VALUE => '2'],
+					[CATEGORY => 'A', NAME => 'CC3', VALUE => '3'],
+					[CATEGORY => 'B', NAME => 'CC4', VALUE => '4'],
+					[CATEGORY => 'A', NAME => 'CC5', VALUE => '5'],
 					] ,
 				) ;
 	
@@ -88,7 +90,7 @@ The method invoked by the command tie %hash, class name. Associates a new hash i
 
 unless('Config::Hierarchical' eq ref $arguments[0])
 	{
-	croak "Argument must be a 'Config::Hierarchical' object!\n" ;
+	die "Argument must be a 'Config::Hierarchical' object!\n" ;
 	}
 	
 my $self = {CONFIG => $arguments[0]} ;
@@ -100,8 +102,7 @@ return($self) ;
 #-------------------------------------------------------------------------------
 
 sub STORE
-{ ## no critic (RequireFinalReturn)
-	
+{
 my ($this, $key, $value) = @_ ;
 
 =head2 STORE
@@ -111,7 +112,7 @@ Dies as this tie is read only.
 =cut
 
 my (undef, $filename, $line) = caller() ;
-$this->{CONFIG}{INTERACTION}{DIE}->("This hash is read only at '$filename:$line'!\n") ;
+die "This hash is read only at '$filename:$line'!\n" ;
 }
 
 #-------------------------------------------------------------------------------
@@ -186,7 +187,7 @@ return($this->{CONFIG}->Exists(NAME => $key)) ;
 #-------------------------------------------------------------------------------
 
 sub DELETE 
-{ ## no critic (RequireFinalReturn)
+{
 
 my ($this, $key) =  @_ ;
 
@@ -197,13 +198,13 @@ Dies as this tie is read only.
 =cut
 
 my (undef, $filename, $line) = caller() ;
-$this->{CONFIG}{INTERACTION}{DIE}->("This hash is read only at '$filename:$line'!\n") ;
+die "This hash is read only at '$filename:$line'!\n" ;
 }
 
 #-------------------------------------------------------------------------------
 
 sub CLEAR 
-{ ## no critic (RequireFinalReturn)
+{
 
 my ($this) = @_ ;
 
@@ -214,7 +215,7 @@ Dies as this tie is read only.
 =cut
 
 my (undef, $filename, $line) = caller() ;
-$this->{CONFIG}{INTERACTION}{DIE}->("This hash is read only at '$filename:$line'!\n") ;
+die "This hash is read only at '$filename:$line'!\n" ;
 }
 
 #-------------------------------------------------------------------------------
